<CsoundSynthesizer>
<CsOptions>
-m 128
</CsOptions>
<CsInstruments>

sr = 44100
ksmps = 32
nchnls = 2
0dbfs = 1
seed 0

/*
Implementing the network now:
A observes whether B_play is running or not.
If so, the sine is one octave lower and softer.
B ovserves whether A_play is running or not.
If so, the impulse sequence is twice as long and louder.
*/

opcode start, 0, S
 ;note that this is k-rate!
 S_instr xin
 event "i", S_instr, 0, 1
endop

opcode start, 0, Sk
 ;note that this is k-rate!
 S_instr, k_p4 xin
 event "i", S_instr, 0, 1, k_p4
endop

opcode sendSigAtEnd, 0, Spo
 S_chn, iSendVal, iNormVal xin
 if release()==1 then
  chnset(k(iSendVal),S_chn)
 else
  chnset(k(iNormVal),S_chn)
 endif
endop

opcode recvSigOnce, k, Spo
 ;only outputs iSendVal if S_chn has changed from 0 to 1
 S_chn, iSendVal, iNormVal xin
 if changed2:k(chnget:k(S_chn))==1 && chnget:k(S_chn)==1 then
  kVal = iSendVal
 else
  kVal = iNormVal
 endif
 xout kVal
endop



instr A

 //set initial status
 kState init 1 ;1=play, 0=pause, -1=do nothing

 //set kState whenever A_play_done or A_pause_done send a signal
 if(recvSigOnce("A_play_done")==1) then
  kState = 0
 elseif(recvSigOnce("A_pause_done")==1) then
  kState = 1
 endif
  
 //get information whether B_play is active or not
 kB_active = active:k("B_play")

 //start play/pause depending on kState and pass the situation
  if(kState==1) then
   start("A_play",kB_active)
  elseif(kState==0) then
   start("A_pause")
  endif
 
 //reset state
 kState = -1
 
endin
schedule("A",0,-1)


instr A_play

 iMidiNote = random:i(70,80)
 iDb = random:i(-30,-20)
 p3 = random:i(3,5)

 //if not alone play softer and one octave lower
 if p4 > 0 then
  puts "A_play: B_play is active!", 1
  iMidiNote -= 12
  iDb -= 10
 endif
 
 aSound = poscil:a(ampdb(iDb),mtof(iMidiNote))
 aOut = linen:a(aSound,p3/2,p3,p3/2)
 
 out(aOut,aOut)
 
 sendSigAtEnd("A_play_done")

endin

instr A_pause

 p3 = random:i(5,8)
 sendSigAtEnd("A_pause_done")

endin



instr B

 //set initial status
 kState init 1 ;1=play, 0=pause, -1=do nothing

 //set kState whenever A_play_done or A_pause_done send a signal
 if(recvSigOnce("B_play_done")==1) then
  kState = 0
 elseif(recvSigOnce("B_pause_done")==1) then
  kState = 1
 endif

 //get information whether A_play is active or not
 kA_active = active:k("A_play")
  
 //start play/pause depending on kState
  if(kState==1) then
   start("B_play",kA_active)
  elseif(kState==0) then
   start("B_pause")
  endif
 
 //reset state
 kState = -1
 
endin
schedule("B",5,-1)

instr B_play

 p3 = random:i(1,2)
 iMediumFreq  = random:i(3,6)
 iDbAdd init 0

 //if not alone play longer and louder
 if p4 > 0 then
  puts "B_play: A_play is active!", 1
  p3 *= 2
  iDbAdd = 6
 endif
 
 kTrig = metro(iMediumFreq)
 if kTrig == 1 then
  kImpulsePitch = random:k(60,70)
  kDb = random:k(-12,0)
  kOffset = random:k(0,1/iMediumFreq)
  event("i","ImpFiltered",kOffset,1,kImpulsePitch,kDb+iDbAdd)
 endif

 sendSigAtEnd("B_play_done")

endin

instr B_pause

 p3 = random:i(5,10)
 sendSigAtEnd("B_pause_done")

endin


instr ImpFiltered

 iMidiNote = p4
 iDb = p5
 iQ = random:i(1/3,2)
 
 aImp = mpulse:a(ampdb(iDb),p3)
 aFilt = mode:a(aImp,mtof(iMidiNote),iQ)
 
 out(aFilt,aFilt)
 
endin

</CsInstruments>
<CsScore>

</CsScore>
</CsoundSynthesizer>
<bsbPanel>
 <label>Widgets</label>
 <objectName/>
 <x>100</x>
 <y>100</y>
 <width>320</width>
 <height>240</height>
 <visible>true</visible>
 <uuid/>
 <bgcolor mode="nobackground">
  <r>255</r>
  <g>255</g>
  <b>255</b>
 </bgcolor>
</bsbPanel>
<bsbPresets>
</bsbPresets>
